/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.animation.messaging;

import java.util.logging.Level;
import java.util.logging.Logger;
import org.robokind.api.animation.Animation;
import org.robokind.api.animation.player.AnimationPlayer;
import org.robokind.api.animation.protocol.AnimationEvent;
import org.robokind.api.common.utils.Listener;
import org.robokind.api.messaging.MessageAsyncReceiver;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class RemoteAnimationPlayerHost {
    private final static Logger theLogger = 
            Logger.getLogger(RemoteAnimationPlayerHost.class.getName());
    private AnimationPlayer myAnimationPlayer;
    private MessageAsyncReceiver<AnimationEvent> myAnimationReceiver;
    private AnimationEventPlayer myEventPlayer;
    
    public RemoteAnimationPlayerHost(){
        myEventPlayer = new AnimationEventPlayer();
    }
    
    public void setAnimationPlayer(AnimationPlayer player){
        myAnimationPlayer = player;
    }
    
    public void setAnimationReceiver(
            MessageAsyncReceiver<AnimationEvent> receiver){
        if(myAnimationReceiver != null){
            myAnimationReceiver.removeMessageListener(myEventPlayer);
        }
        myAnimationReceiver = receiver;
        if(myAnimationReceiver != null){
            myAnimationReceiver.addMessageListener(myEventPlayer);
        }
    }
    
    public class AnimationEventPlayer implements Listener<AnimationEvent>{

        @Override
        public void handleEvent(AnimationEvent event) {
            if(event == null){
                theLogger.warning("Ignoring null AnimaionEvent.");
                return;
            }
            Animation anim = event.getAnimation();
            if(anim == null){
                theLogger.warning(
                        "Ignoring null Animaion from AnimationEvent.");
                return;
            }else if(myAnimationPlayer == null){
                theLogger.warning("Animation Player is null.  "
                        + "Ignoring AnimaionEvent.");
                return;
            }
            theLogger.log(Level.INFO, 
                    "Sending Animation: {0}, to AnimationPlayer: {1}.", 
                    new Object[]{
                        anim.getVersion().display(),
                        myAnimationPlayer.getAnimationPlayerId()});
            
            myAnimationPlayer.playAnimation(event.getAnimation());
        }
    }
}
