/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.animation.osgi;

import java.util.Map;
import java.util.Properties;
import org.robokind.api.animation.library.AnimationLibrary;
import org.robokind.api.animation.player.AnimationPlayer;
import org.robokind.api.animation.player.AnimationTriggerHandler;
import org.robokind.api.common.osgi.lifecycle.AbstractLifecycleProvider;
import org.robokind.api.common.osgi.lifecycle.DescriptorListBuilder;
import org.robokind.api.common.triggering.Trigger;
import org.robokind.api.common.triggering.TriggerHandler;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class AnimationTriggerHandlerLifecycleProvider extends 
        AbstractLifecycleProvider<TriggerHandler, AnimationTriggerHandler> {
    private final static String theDepPlayerId = "animPlayer";
    private final static String theDepLibraryId = "animLibrary";
    
    public AnimationTriggerHandlerLifecycleProvider(
            String animPlayerId, String animLibraryId){
        super(new DescriptorListBuilder()
                .addId(theDepPlayerId, AnimationPlayer.class, 
                        AnimationPlayer.PROP_PLAYER_ID, animPlayerId)
                .addId(theDepLibraryId, AnimationLibrary.class, 
                        AnimationLibrary.PROP_ANIM_PLAYER_ID, animLibraryId)
                .getDescriptors());
        myRegistrationProperties = new Properties();
        myRegistrationProperties.put(
                Trigger.PROP_TRIGGER_TYPE, 
                AnimationTriggerHandler.ANIMATION_TRIGGER_TYPE);
    }

    @Override
    protected AnimationTriggerHandler create(Map<String, Object> services) {
        AnimationPlayer player = (AnimationPlayer)services.get(theDepPlayerId);
        AnimationLibrary lib = (AnimationLibrary)services.get(theDepLibraryId);
        return new AnimationTriggerHandler(lib, player);
    }

    @Override
    protected void handleChange(String serviceId, Object service) {
        if(theDepPlayerId.equals(serviceId)){
            myService.setPlayer((AnimationPlayer)service);
        }else if(theDepLibraryId.equals(serviceId)){
            myService.setAnimationLibrary((AnimationLibrary)service);
        }
    }

    @Override
    public Class<TriggerHandler> getServiceClass() {
        return TriggerHandler.class;
    }
}
